@@ -1,6 +1,6 @@
 #!perl -w
 #
-# $Id: exe_wrap.pl,v 1.49 2004/09/27 21:10:52 epaepa Exp $
+# $Id: exe_wrap.pl,v 1.67 2006/04/23 16:26:59 rmeden Exp $
 # This is a quick XMLTV shell routing to use with the windows exe
 #
 # A single EXE is needed to allow sharing of modules and dlls of all the
@@ -20,23 +20,26 @@ use Carp;
 
 $Carp::MaxEvalLen=40; # limit confess output
 
-# Check for error of running from 'Run' dialogue box with redirection,
-# which Run doesn't understand,
 #
-if (grep /[<>|]/, @ARGV) {
-    warn <<END
-The command line:
-
-$0 @ARGV
-
-contains redirections, so should be run from a command prompt window.
-In general, it's a good idea to always run xmltv from a command prompt
-so that you can see any errors and warnings produced.
-END
-      ;
-    sleep 10;
-    exit 1;
-}
+# this check should not be done, at least not this way. it prevents some regular expressions!
+#
+## Check for error of running from 'Run' dialogue box with redirection,
+## which Run doesn't understand,
+##
+#if (grep /[<>|]/, @ARGV) {
+#    warn <<END
+#The command line:
+#
+#$0 @ARGV
+#
+#contains redirections, so should be run from a command prompt window.
+#In general, it's a good idea to always run xmltv from a command prompt
+#so that you can see any errors and warnings produced.
+#END
+#      ;
+#    sleep 10;
+#    exit 1;
+#}
 
 #
 # check for --quiet
@@ -66,7 +69,7 @@ print STDERR "Timezone is $ENV{TZ}\n" unless $opt_quiet;
 $cmd = shift || "";
 
 # --version (and abbreviations thereof)
-my $VERSION = '0.5.35';
+my $VERSION = '0.5.43';
 if (index('--version', $cmd) == 0 and length $cmd >= 3) {
     print "xmltv $VERSION\n";
     exit;
@@ -88,11 +91,14 @@ END
 # some programs use a "share" directory
 #
 if ($cmd eq 'tv_grab_uk_rt'
+ or $cmd eq 'tv_grab_au'
+ or $cmd eq 'tv_grab_ch'
+ or $cmd eq 'tv_grab_be'
  or $cmd eq 'tv_grab_uk_bleb'
  or $cmd eq 'tv_grab_it'
- or $cmd eq 'tv_grab_nl'
  or $cmd eq 'tv_grab_na_dd',
  or $cmd eq 'tv_grab_na_icons',
+ or $cmd eq 'tv_grab_huro',
  or $cmd eq 'tv_grab_de_tvtoday'
  )
 {
@@ -111,6 +117,25 @@ if ($cmd eq 'tv_grab_uk_rt'
     }
 }
 
+#
+# special hack, allow "exec" to execute an arbitrary script
+# This will be used to allow XMLTV.EXE modules to be used on beta code w/o an alpha exe
+#
+# Note, no extra modules are included in the EXE.  There is no guarantee this will work
+# it is an unsupported hack.
+#
+# syntax XMLTV.EXE exec filename --options
+#
+if ($cmd eq 'exec')
+{
+   my $exe=shift;
+   $0=$exe;
+   do $exe;
+   print STDERR $@ if length($@);
+   exit 1 if length($@);
+   exit 0;
+}
+  
 #
 # scan through attached files and execute program if found
 #
@@ -130,6 +155,7 @@ foreach my $exe (split(/ /,$files))
     $0 = $_;        # set $0 to our script
     do $exe;
     print STDERR $@ if length($@);
+    exit 1 if length($@);
     exit 0;
 }
 
